@@ -13,10 +13,10 @@
 #' PUT(b2, body = "A simple text string")
 #' PUT(b2, body = list(x = "A simple text string"))
 #' PUT(b2, body = list(y = upload_file(system.file("CITATION"))))
-PUT <- function(url = NULL, config = list(), body = NULL, multipart = TRUE, ..., handle = NULL) {
+PUT <- function(url = NULL, config = list(), ..., body = NULL, multipart = TRUE,
+                handle = NULL) {
   hu <- handle_url(handle, url, ...)
-  make_request("put", hu$handle, hu$url, body = body,
-    multipart = multipart, config = config)
-}
+  config <- make_config(config, ...)
 
-put_config <- post_config
+  make_request("put", hu$handle, hu$url, config, body_config(body, multipart))
+}
