@@ -1,9 +1,8 @@
 parse_query <- function(query) {
   params <- vapply(str_split(query, "&")[[1]], str_split_fixed, "=", 2,
     FUN.VALUE = character(2))
-  values <- type.convert(curlUnescape(params[2, ]), as.is = TRUE)
-  names <- params[1, ]
-  setNames(as.list(values), names)
+  
+  setNames(as.list(curlUnescape(params[2, ])), curlUnescape(params[1, ]))
 }
 
 compose_query <- function(elements) {
